@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 
 #
-# Copyright (C) 2018 Joelle Maslak
+# Copyright (C) 2018,2020 Joelle Maslak
 # All Rights Reserved - See License
 #
 
@@ -11,7 +11,7 @@ use warnings;
 
 package Dist::Zilla::PluginBundle::Author::JMASLAK;
 # ABSTRACT: JMASLAK's Plugin Bundle
-$Dist::Zilla::PluginBundle::Author::JMASLAK::VERSION = '1.182070';
+$Dist::Zilla::PluginBundle::Author::JMASLAK::VERSION = '1.202110';
 
 use Moose;
 use Dist::Zilla;
@@ -42,7 +42,7 @@ AUTOPLUG: {
     use Dist::Zilla::Plugin::ReadmeAnyFromPod;
     use Dist::Zilla::Plugin::Test::ChangesHasContent;
     use Dist::Zilla::Plugin::Test::EOL;
-    use Dist::Zilla::Plugin::Test::Kwalitee::Extra;
+    use Dist::Zilla::Plugin::Test::Kwalitee;
     use Dist::Zilla::Plugin::Test::NoTabs;
     use Dist::Zilla::Plugin::Test::ReportPrereqs;
     use Dist::Zilla::Plugin::Test::TrailingSpace;
@@ -96,7 +96,7 @@ sub configure {
     $self->add_plugins( [ 'ReadmeAnyFromPod' => { type => 'pod', filename => 'README.pod' } ] );
     $self->add_plugins('Test::ChangesHasContent');
     $self->add_plugins('Test::EOL');
-    $self->add_plugins('Test::Kwalitee::Extra');
+    $self->add_plugins('Test::Kwalitee');
     $self->add_plugins('Test::NoTabs');
     $self->add_plugins('Test::ReportPrereqs');
     $self->add_plugins(
@@ -265,7 +265,7 @@ Dist::Zilla::PluginBundle::Author::JMASLAK - JMASLAK's Plugin Bundle
 
 =head1 VERSION
 
-version 1.182070
+version 1.202110
 
 =head1 DESCRIPTION
 
@@ -309,7 +309,7 @@ It is somewhat equivilent to:
 
     [Test::ChangesHasContent]
     [Test::EOL]
-    [Test::Kwalitee::Extra]
+    [Test::Kwalitee]
     [Test::NoTabs]
     [Test::ReportPrereqs]
 
@@ -372,7 +372,7 @@ Joelle Maslak <jmaslak@antelope.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Joelle Maslak.
+This software is copyright (c) 2018,2020 by Joelle Maslak.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
